from sunweg.util import Status

class Inverter:
    
    def __init__(self, id:int, name:str, sn:str, total_energy:float, today_energy:float, power_factor:float, frequency:float,
                 power:float, status:Status, temperature:int) -> None:
        self.id = id
        self.name = name
        self.sn = sn
        self.total_energy = total_energy
        self.today_energy = today_energy
        self.power_factor = power_factor
        self.frequency = frequency
        self.power = power
        self.status = status
        self.temperature = temperature
        self.phases = []
        self.mppts = []
    
    def __str__(self) -> str:
        return str(self.__class__) + ": " + str(self.__dict__)

class Phase:
    def __init__(self, name:str, voltage:float, amperage:float, status_voltage:Status, status_amperage:Status) -> None:
        self.name = name
        self.voltage = voltage
        self.amperage = amperage
        self.status_voltage = status_voltage
        self.status_amperage = status_amperage
    def __str__(self) -> str:
        return str(self.__class__) + ": " + str(self.__dict__)

class MPPT:
    def __init__(self, name:str) -> None:
        self.name = name
        self.strings = []

    def __str__(self) -> str:
        return str(self.__class__) + ": " + str(self.__dict__)

class String:
    def __init__(self, name:str, voltage:float, amperage:float, status:Status) -> None:
        self.name = name
        self.voltage = voltage
        self.amperage = amperage
        self.status = status
    
    def __str__(self) -> str:
        return str(self.__class__) + ": " + str(self.__dict__)


SUNWEG_URL = 'https://api.sun.weg.net/'
SUNWEG_LOGIN_PATH = 'login/autenticacao'
SUNWEG_PLANT_LIST_PATH = 'usinas/getpaineloperacao?procurar=&integrador=&franqueado=&portal=&alarme=&planos=%5B%220%22,%221%22,%222%22,%223%22,%224%22%5D&status=%5B%221%22,%222%22,%223%22,%224%22,%225%22%5D'
SUNWEG_PLANT_DETAIL_PATH = 'usinas/view?idusina='
SUNWEG_INVERTER_DETAIL_PATH = 'inversores/view?id='


from datetime import datetime

class Plant:
    inverters = []
    
    def __init__(self, id:int, name:str, total_power:float, kwh_per_kwp:float, performance_rate:float, saving:float,
                    today_energy:float, total_energy:float, total_carbon_saving:float, last_update:datetime):
        self.id = id
        self.name = name
        self.total_power = total_power
        self.kwh_per_kwp = kwh_per_kwp
        self.performance_rate = performance_rate
        self.saving = saving
        self.today_energy = today_energy
        self.total_energy = total_energy
        self.total_carbon_saving = total_carbon_saving
        self.last_update = last_update
    
    def __str__(self) -> str:
        return str(self.__class__) + ": " + str(self.__dict__)